/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * Author: Siamak Haschemi
 * Contact: haschemi@informatik.hu-berlin.de
 */
package net.sourceforge.osgi.deployment.maven;

/**
 * <p>
 * From the Deployment Admin Specification:
 * </p>
 * <p>
 * A Deployment Package consists of installable <i>resources</i>. Resources are described in the <i>Name sections</i> of the Manifest. They are stored in the
 * JAR file under a path. This path is called the <i>resource id</i>. Subsets of these resources are the bundles. Bundles are treated differently from the
 * other resources by the Deployment Admin service. Non-bundle resources are called <i>processed resources</i>.
 * </p>
 * 
 * @author Siamak Haschemi, haschemi@informatik.hu-berlin.de
 */
public interface IResource {
  /**
   * The resourceId of the resource specifies the path and the name of the resource. Implementations can directly return the resourceId or compute it.
   * 
   * @return the path of the resource
   */
  String getResourceId();
}
