/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * 
 * Author: Siamak Haschemi
 * Contact: haschemi@informatik.hu-berlin.de
 */
package net.sourceforge.osgi.deployment.maven.manifest;

import net.sourceforge.osgi.deployment.maven.IDeploymentPluginContext;

/**
 * An {@link ManifestException} is thrown if any error occures while processing the input data from the {@link IDeploymentPluginContext} to generate the
 * manifest file.
 * 
 * @author Siamak Haschemi, haschemi@informatik.hu-berlin.de
 * 
 */
public final class ManifestException extends RuntimeException {
  private static final long serialVersionUID = -5665247031595519354L;

  /**
   * Constructor which creates an Exception chain with a message and a {@link Throwable} as the cause of this exception.
   * 
   * @param p_message
   *          the message of this exception
   * @param p_cause
   *          the cause of this exception
   */
  public ManifestException(final String p_message, final Throwable p_cause) {
    super(p_message, p_cause);
  }

  /**
   * Constructor which creates an Exception chain with a {@link Throwable} as the cause of this exception. No message is provided.
   * 
   * @param p_cause
   *          p_cause the cause of this exception
   */
  public ManifestException(final Throwable p_cause) {
    super(p_cause);
  }

  /**
   * Constructor which creates an Exception with no original cause ({@link Throwable}) . Only a message is provided.
   * 
   * @param p_message
   *          the message of this exception
   */
  public ManifestException(final String p_message) {
    super(p_message);
  }
}
